@@ -245,11 +245,14 @@ shouldEditTableColumn: (NSTableColumn*) aTableColumn
   NSString* hex = [WBColorCell hexStringWithColor: c];
   const char* cStr = [hex UTF8String];
   NSInteger rowIndex = [mTableView selectedRow];
-  bec::NodeId node;
-  node.append(rowIndex);
-  std::string s = std::string(cStr);
-  mValueInspector->set_field(node, ::bec::ValueInspectorBE::Value, s);
-  [mTableView reloadData];
+  if (rowIndex >= 0)
+  {
+    bec::NodeId node;
+    node.append(rowIndex);
+    std::string s = std::string(cStr);
+    mValueInspector->set_field(node, ::bec::ValueInspectorBE::Value, s);
+    [mTableView reloadData];
+  }
 }
 
 
