@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -304,13 +304,22 @@ std::string UtilitiesImpl::get_clipboard_text()
 
 void UtilitiesImpl::open_url(const std::string &url)
 {
+  char *quoted_url = g_uri_escape_string(url.c_str(), 
+                                         G_URI_RESERVED_CHARS_GENERIC_DELIMITERS 
+                                         G_URI_RESERVED_CHARS_SUBCOMPONENT_DELIMITERS, 
+                                         FALSE);
+  
   const gchar *argv[] = {
     "xdg-open",
-    url.c_str(),
+    quoted_url,
     NULL 
   };
   GError *error = NULL;
-  if (!g_spawn_async(NULL, (gchar**)argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, &error))
+  gboolean result = g_spawn_async(NULL, (gchar**)argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, &error);
+  
+  free(quoted_url);
+  
+  if (!result)
   {
     char *err = g_strdup_printf("Error opening url with xdg-open: %s", error->message);
     g_error_free(error);
